@@ -212,9 +212,9 @@ def main():
             else:
                 t=db_class.get_feed_from_feed_db(field_name="name",query="")
             if t:
-                feed_table = Table(title="Feed Database",expand=True,safe_box=True)
+                feed_table = Table(title="Feed Database",safe_box=True,expand=True)
                 for i in t[0].to_dict().keys():
-                    feed_table.add_column(i, justify="center", style="cyan", no_wrap=True)
+                    feed_table.add_column(i, justify="center", style="cyan",max_width=20)
                 for i in t:
                     feed_table.add_row(*map(str,list(i.to_dict().values())))
                 console.print(feed_table)
